<!DOCTYPE kpartgui>
<kpartgui name="ksame" version="9">
<MenuBar>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
	<Action name="random_board"/>
	<Separator/>
  	<Action name="options_configure_keybinding"/>
  </Menu>	
</MenuBar>
</kpartgui>
